@@ -738,7 +738,11 @@ class VirtualService(HttpClient, KempBaseObjectModel):
         api = super(VirtualService, self).to_api_dict()
         if not self._waf:
             for entry in self._waf_params:
-                del api[entry]
+                # If it doesn't exist don't do anything
+                try:
+                    del api[entry]
+                except KeyError:
+                    pass
         return api
 
     def _get_base_parameters(self):
@@ -931,7 +935,9 @@ class VirtualService(HttpClient, KempBaseObjectModel):
         self.rsruleprecedence = service.get('RSRulePrecedence', None)
         self.rsruleprecedencepos = service.get('RSRulePrecedencePos', None)
         self.enhancedhealthchecks = service.get('EnhancedHealthChecks', None)
-        self.rsminimum = service.get('RsMinimum', None)
+        rs_min = service.get('RsMinimum', None)
+        self.rsminimum = None if int(rs_min) == 0 else rs_min
+
 
     def create_sub_virtual_service(self):
         """VirtualService factory with pre-configured LoadMaster connection
